@@ -21,8 +21,7 @@ import org.gnu.gtk.event.GtkEventType;
 public class CellEditable extends GObject 
 {
 	public CellEditable() {
-		setHandle(newObject());
-		initializeEventHandlers();
+		super(newObject());
 	}
 	
 	/**
@@ -61,6 +60,8 @@ public class CellEditable extends GObject
 		int i = findListener(listeners, listener);
 		if (i == -1) {
 			if (null == listeners) {
+				evtMap.initialize(this, CellEditableEvent.Type.EDITING_DONE);
+				evtMap.initialize(this, CellEditableEvent.Type.REMOVE_WIDGET);
 				listeners = new Vector();
 			}
 			listeners.addElement(listener);
@@ -76,6 +77,8 @@ public class CellEditable extends GObject
 			listeners.remove(i);
 		}
 		if (0 == listeners.size()) {
+			evtMap.uninitialize(this, CellEditableEvent.Type.EDITING_DONE);
+			evtMap.uninitialize(this, CellEditableEvent.Type.REMOVE_WIDGET);
 			listeners = null;
 		}
 	}
@@ -116,23 +119,16 @@ public class CellEditable extends GObject
 		fireCellEditableEvent(event);
 	}
 
-	/** Are events initialized? */
-	private boolean eventsInitialized = false;
-
-	protected void initializeEventHandlers() {
-		if (!eventsInitialized) {
-			evtMap.initialize(this);
-			eventsInitialized = true;
-		}
-	}
-		
-
 	public Class getEventListenerClass(String signal) {
-		return evtMap.getListenerClass(signal);
+		Class cls = evtMap.getEventListenerClass(signal);
+		if (cls == null) cls = super.getEventListenerClass(signal);
+		return cls;
 	}
 
 	public GtkEventType getEventType(String signal) {
-		return evtMap.getEventType(signal);
+		GtkEventType et = evtMap.getEventType(signal);
+		if (et == null) et = super.getEventType(signal);
+		return et;
 	}
 
 	private static EventMap evtMap = new EventMap();
