@@ -46,7 +46,6 @@ public class Dialog extends Window {
 	 */
 	public Dialog() {
 		super(Dialog.gtk_dialog_new());
-		initializeEventHandlers();
 	}
 
 	/**
@@ -54,7 +53,6 @@ public class Dialog extends Window {
 	 */
 	public Dialog(int handle) {
 		super(handle);
-		initializeEventHandlers();
 	}
 
 	/**
@@ -176,6 +174,8 @@ public class Dialog extends Window {
 		int i = findListener(dialogListeners, listener);
 		if (i == -1) {
 			if (null == dialogListeners) {
+				evtMap.initialize(this, DialogEvent.Type.CLOSE);
+				evtMap.initialize(this, DialogEvent.Type.RESPONSE);
 				dialogListeners = new Vector();
 			}
 			dialogListeners.addElement(listener);
@@ -191,6 +191,8 @@ public class Dialog extends Window {
 			dialogListeners.remove(i);
 		}
 		if (0 == dialogListeners.size()) {
+			evtMap.uninitialize(this, DialogEvent.Type.CLOSE);
+			evtMap.uninitialize(this, DialogEvent.Type.RESPONSE);
 			dialogListeners = null;
 		}
 	}
@@ -218,14 +220,6 @@ public class Dialog extends Window {
 		fireButtonEvent(de);
 	}
 
-	protected void initializeEventHandlers() {
-		if (!eventsInitialized) {
-			super.initializeEventHandlers();
-			evtMap.initialize(this);
-			eventsInitialized = true;
-		}
-	}
-
 	public Class getEventListenerClass(String signal) {
 		Class cls = evtMap.getEventListenerClass(signal);
 		if (cls == null) cls = super.getEventListenerClass(signal);
