@@ -17,11 +17,9 @@ package org.gnu.gtk;
 public class Progress extends Widget 
 {	
 	Progress(int handle) {
-	    setHandle(handle);
+	    super(handle);
 	}
 
-	Progress() {}
-
 	//
 	// This class is all deprecated as of Gnome 2
 	//
