@@ -21,14 +21,14 @@ public class RcStyle extends GObject
 	 * Construct a new RcStyle.
 	 */
 	public RcStyle() {
-		setHandle(RcStyle.gtk_rc_style_new());
+		super(gtk_rc_style_new());
 	}
 	
 	/**
 	 * Construct a new RcStyle from a given handle to a native resource.
 	 */
 	public RcStyle(int handle) {
-		this.setHandle(handle);
+		super(handle);
 	}
 	
 	/**
