@@ -27,15 +27,13 @@ public class TreeViewColumn extends GObject {
 	 * Creates a new Column
 	 */
 	public TreeViewColumn() {
-		setHandle(gtk_tree_view_column_new());
-		initializeEventHandlers();
+		super(gtk_tree_view_column_new());
 	}
 
 	/**
 	 */
-	protected TreeViewColumn(int h) {
-		setHandle(h);
-		initializeEventHandlers();
+	protected TreeViewColumn(int handle) {
+		super(handle);
 	}
 
 	/**
@@ -401,6 +399,7 @@ public class TreeViewColumn extends GObject {
 		int i = Widget.findListener(columnClickedListeners, listener);
 		if (i == -1) {
 			if (null == columnClickedListeners) {
+				evtMap.initialize(this, TreeViewColumnEvent.Type.CLICKED);
 				columnClickedListeners = new Vector();
 			}
 			columnClickedListeners.addElement(listener);
@@ -417,6 +416,7 @@ public class TreeViewColumn extends GObject {
 			columnClickedListeners.remove(i);
 		}
 		if (0 == columnClickedListeners.size()) {
+			evtMap.uninitialize(this, TreeViewColumnEvent.Type.CLICKED);
 			columnClickedListeners = null;
 		}
 	}
@@ -437,26 +437,20 @@ public class TreeViewColumn extends GObject {
 		fireSelectionEvent(new TreeViewColumnEvent(this));
 	}
 
-	/** Are events initialized? */
-	private boolean eventsInitialized = false;
-
-	protected void initializeEventHandlers() {
-		if (!eventsInitialized) {
-			evtMap.initialize(this);
-			eventsInitialized = true;
-		}
+	public Class getEventListenerClass(String signal) {
+	    Class cls = evtMap.getEventListenerClass(signal);
+		if (cls == null) cls = super.getEventListenerClass(signal);
+		return cls;
 	}
 
-        public Class getEventListenerClass(String signal) {
-	    return evtMap.getListenerClass(signal);
+	public GtkEventType getEventType(String signal) {
+	    GtkEventType et = evtMap.getEventType(signal);
+		if (et == null) et = super.getEventType(signal);
+		return et;
 	}
 
-        public GtkEventType getEventType(String signal) {
-	    return evtMap.getEventType(signal);
-	}
-
-        private static EventMap evtMap = new EventMap();
-        static {
+	private static EventMap evtMap = new EventMap();
+	static {
 		addEvents(evtMap);
 	}
 
