@@ -24,8 +24,7 @@ public class VBox extends Box {
 	 * @param spacing The  number of pixels to place by default between children.
 	 */
 	public VBox (boolean homogenous, int spacing) {
-		setHandle(gtk_vbox_new (homogenous, spacing));
-		initializeEventHandlers();
+		super(gtk_vbox_new (homogenous, spacing));
 	}
 	
 	/**
@@ -33,13 +32,8 @@ public class VBox extends Box {
 	 */
 	public VBox(int handle) {
 	    super(handle);
-		initializeEventHandlers();
 	}
 	
-	protected VBox() {}
-	
-	protected void noopInit() {}
-
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
