@@ -1,12 +1,7 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2002 the Java-Gnome Team, all rights reserved.
- *
- * The Java-Gnome Team Members:
- *   Jean Van Wyk <jeanvanwyk@iname.com>
- *   Jeffrey S. Morgan <jeffrey.morgan@bristolwest.com>
- *   Dan Bornstein <danfuzz@milk.com>
+ * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome bindings library is free software distributed under
  * the terms of the GNU Library General Public License version 2.
@@ -26,18 +21,22 @@ public class AdjustmentEvent extends GtkEvent {
 		super(id, name);
 	    }
 
-	    /**
-	     * This event indicates that the menu item has been activated.
-	     */
-	    public static final Type VALUE_CHANGED = 
-		new Type(1, "VALUE_CHANGED");
+	    public static final Type VALUE_CHANGED = new Type(1, "VALUE_CHANGED");
+	
+	    public static final Type CHANGED = new Type(2, "CHANGED");
 	}
 
 	/**
-	 * Construct a FocusEvent object.
+	 * Construct a AdjustmentEvent object.
 	 */
-	public AdjustmentEvent(Object source) {
-		super(source, Type.VALUE_CHANGED);
+	public AdjustmentEvent(Object source, GtkEventType type) {
+		super(source, type);
 	}
 
+	/**
+	 * @return True if the type of this event is the same as that stated.
+	 */
+	public boolean isOfType(AdjustmentEvent.Type aType) {
+		return (type.getID() == aType.getID());
+	}
 }
